@@ -132,7 +132,7 @@ class TestDXTabCompletion(unittest.TestCase):
         self.assert_completion("dx ls my", "my applet ")
         self.assert_completion("dx ls", "ls ")
         self.assert_completion("dx run my", "my applet ")
-        #self.assert_completion("dx ls ", "my applet ")
+        self.assert_completion("dx ls ", "my applet ")
 
     def test_pipeline_completion(self):
         dxpipeline = dxpy.new_dxrecord(name="my workflow", types=["pipeline"])
