@@ -1099,7 +1099,7 @@ class TestPrettyPrint(unittest.TestCase):
 
 class TestHTTPResponses(unittest.TestCase):
     def test_content_type_no_sniff(self):
-        resp = dxpy.api.user_describe("user-000000000000000000000000", want_full_response=True)
+        resp = dxpy.api.system_find_projects({'limit': 1}, want_full_response=True)
         self.assertEqual(resp.headers['x-content-type-options'], 'nosniff')
 
 class TestDataobjectFunctions(unittest.TestCase):
@@ -1139,8 +1139,9 @@ class TestResolver(unittest.TestCase):
 
     def test_basic_ops(self):
         from dxpy.utils.resolver import resolve_existing_path, ResolutionError
+        resolve_existing_path('')
         with self.assertRaises(ResolutionError):
-            resolve_existing_path('')
+            resolve_existing_path('', allow_empty_string=False)
         proj_id, path, entity_id = resolve_existing_path(':')
         self.assertEqual(proj_id, dxpy.WORKSPACE_ID)
 
